aboutsummaryrefslogtreecommitdiff
path: root/src/pkg/runtime
diff options
context:
space:
mode:
Diffstat (limited to 'src/pkg/runtime')
-rw-r--r--src/pkg/runtime/netpoll_windows.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/pkg/runtime/netpoll_windows.c b/src/pkg/runtime/netpoll_windows.c
index e2153c540e..7a95380a33 100644
--- a/src/pkg/runtime/netpoll_windows.c
+++ b/src/pkg/runtime/netpoll_windows.c
@@ -16,9 +16,9 @@ extern void *runtime·GetQueuedCompletionStatus;
#define INVALID_HANDLE_VALUE ((uintptr)-1)
-// net_anOp must be the same as beginning of net.anOp. Keep these in sync.
-typedef struct net_anOp net_anOp;
-struct net_anOp
+// net_op must be the same as beginning of net.operation. Keep these in sync.
+typedef struct net_op net_op;
+struct net_op
{
// used by windows
Overlapped o;
@@ -66,7 +66,7 @@ runtime·netpoll(bool block)
{
uint32 wait, qty, key;
int32 mode, errno;
- net_anOp *o;
+ net_op *o;
G *gp;
if(iocphandle == INVALID_HANDLE_VALUE)